@@ -1,9 +1,9 @@
 package Sah::Schema::cpan::pause_id;
 
-our $DATE = '2018-04-06'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2018-09-02'; # DATE
+our $VERSION = '0.003'; # VERSION
 
- our $schema = ["str",{match=>qr([a-z][a-z0-9]{1,8}),summary=>"PAUSE author ID","x.perl.coerce_rules"=>["str_toupper"]},{}];
+ our $schema = ["str",{match=>qr([A-Z][A-Z0-9]{1,8}),summary=>"PAUSE author ID","x.perl.coerce_rules"=>["str_toupper"]},{}];
 
 
 1;
@@ -22,7 +22,7 @@ Sah::Schema::cpan::pause_id - PAUSE author ID
 
 =head1 VERSION
 
-This document describes version 0.002 of Sah::Schema::cpan::pause_id (from Perl distribution Sah-Schemas-CPAN), released on 2018-04-06.
+This document describes version 0.003 of Sah::Schema::cpan::pause_id (from Perl distribution Sah-Schemas-CPAN), released on 2018-09-02.
 
 =head1 HOMEPAGE
 
